This directory contains example notebooks for `Triglav`. The notebooks are organized as follows:

- [Usage Example](01_random_dataset.ipynb) - A notebook that demonstrates how to use `Triglav` with a randomly generated dataset.

- [Crohn's Disease vs. Healthy Controls (Stability)](Diseased-Gut-Analysis/16S_CD_stability.ipynb) - A notebook that compares feature stability scores across a range of approaches to `Triglav`.

- [Crohn's Disease vs. Healthy Controls (End to End)](Diseased-Gut-Analysis/16S_end_to_end.ipynb) - A notebook that demonstrates how to use `Triglav` to find differences in the microbial communities along the healthy human colon.
